==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/DisMaxJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;
import java.util.ArrayList;

import static com.google.common.collect.Lists.*;

/**
 * @author kimchy (Shay Banon)
 */
public class DisMaxJsonQueryBuilder extends BaseJsonQueryBuilder {

    private ArrayList<JsonQueryBuilder> queries = newArrayList();

    private float boost = -1;

    private float tieBreakerMultiplier = -1;

    public DisMaxJsonQueryBuilder add(JsonQueryBuilder queryBuilder) {
        queries.add(queryBuilder);
        return this;
    }

    public DisMaxJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    public DisMaxJsonQueryBuilder tieBreakerMultiplier(float tieBreakerMultiplier) {
        this.tieBreakerMultiplier = tieBreakerMultiplier;
        return this;
    }

    @Override protected void doJson(JsonBuilder builder) throws IOException {
        builder.startObject("disMax");
        if (tieBreakerMultiplier != -1) {
            builder.field("tieBreakerMultiplier", tieBreakerMultiplier);
        }
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.startArray("queries");
        for (JsonQueryBuilder queryBuilder : queries) {
            queryBuilder.toJson(builder);
        }
        builder.endArray();
        builder.endObject();
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/DisMaxJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;
import java.util.ArrayList;

import static com.google.common.collect.Lists.*;

/**
 * A query that generates the union of documents produced by its sub-queries, and that scores each document
 * with the maximum score for that document as produced by any sub-query, plus a tie breaking increment for any
 * additional matching sub-queries.
 *
 * @author kimchy (shay.banon)
 */
public class DisMaxJsonQueryBuilder extends BaseJsonQueryBuilder {

    private ArrayList<JsonQueryBuilder> queries = newArrayList();

    private float boost = -1;

    private float tieBreakerMultiplier = -1;

    /**
     * Add a sub-query to this disjunction.
     */
    public DisMaxJsonQueryBuilder add(JsonQueryBuilder queryBuilder) {
        queries.add(queryBuilder);
        return this;
    }

    /**
     * Sets the boost for this query.  Documents matching this query will (in addition to the normal
     * weightings) have their score multiplied by the boost provided.
     */
    public DisMaxJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    /**
     * The score of each non-maximum disjunct for a document is multiplied by this weight
     * and added into the final score.  If non-zero, the value should be small, on the order of 0.1, which says that
     * 10 occurrences of word in a lower-scored field that is also in a higher scored field is just as good as a unique
     * word in the lower scored field (i.e., one that is not in any higher scored field.
     */
    public DisMaxJsonQueryBuilder tieBreaker(float tieBreakerMultiplier) {
        this.tieBreakerMultiplier = tieBreakerMultiplier;
        return this;
    }

    @Override protected void doJson(JsonBuilder builder, Params params) throws IOException {
        builder.startObject("disMax");
        if (tieBreakerMultiplier != -1) {
            builder.field("tieBreakerMultiplier", tieBreakerMultiplier);
        }
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.startArray("queries");
        for (JsonQueryBuilder queryBuilder : queries) {
            queryBuilder.toJson(builder, params);
        }
        builder.endArray();
        builder.endObject();
    }
}
